==> HostCMS.Free_6.7.tar.gz: modules/lib/property/i18n/en.php <==
<?php
/**
 * Libs.
 *
 * @package HostCMS
 * @subpackage Lib
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Parameters of sample dynamic pages',
	'markDeleted_success' => 'Parameter of sample dynamic page deleted successfully!',
	'lib_property_show_title' => 'Parameters of sample dynamic page "%s"',
	'lib_property_parametr' => 'Parameter',
	'lib_property_add' => 'Add',
	'lib_property_form_title_add' => 'Add parameter of sample dynamic page',
	'name' => '<acronym title="Parameter name of sample dynamic page">Parameter name</acronym>',
	'description' => '<acronym title="Description of parameter of sample dynamic page">Parameter description</acronym>',
	'varible_name' => '<acronym title="Name of parameter variable of sample dynamic page">Variable name</acronym>',
	'type' => "<acronym title=\"Type of additional property of parameter of sample dynamic page.\">Type</acronym>",
	'default_value' => '<acronym title="Default parameter value of dynamic page">Default value</acronym>',
	'sorting' => '<acronym title="Sorting order of parameter of dynamic page">Sorting order</acronym>',
	'lib_property_form_title_edit' => 'Edit parameter of sample dynamic page',
	'id' => 'Id',
	'lib_id' => 'Lib Id',
	'lib_property_type_0' => 'Input field',
	'lib_property_type_1' => 'Checkbox',
	'lib_property_type_2' => 'XSL template',
	'lib_property_type_3' => 'List',
	'lib_property_type_4' => 'SQL query',
	'lib_property_type_5' => 'Large text field',
	'value' => 'Value',
	'multivalue' => 'Multiple values',
	'copy_from' => ' [Copy of %s]',
	'sql_request' => '<acronym title="Text of SQL query">SQL query</acronym>',
	'sql_caption_field' => '<acronym title="Table field acting as header when displaying query information">Header field</acronym>',
	'sql_value_field' => '<acronym title="Table field from which the value is extracted">Value field</acronym>',
	'edit_success' => 'Information on dynamic page parameters added/updated successfully.',
	'edit_error' => 'Information on dynamic page parameters added/updated successfully.',
	'apply_success' => 'Information modified successfully',
	'copy_success' => 'Parameters of sample dynamic pages copied successfully.',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
);

==> HostCMS.Free_7.0.tar.gz: modules/lib/property/i18n/en.php <==
<?php
/**
 * Libs.
 *
 * @package HostCMS
 * @subpackage Lib
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2021 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Parameters of sample dynamic pages',
	'markDeleted_success' => 'Parameter of sample dynamic page deleted successfully!',
	'lib_property_show_title' => 'Parameters of sample dynamic page "%s"',
	'lib_property_parametr' => 'Parameter',
	'lib_property_add' => 'Add',
	'lib_property_form_title_add' => 'Add parameter of sample dynamic page',
	'name' => 'Parameter name',
	'description' => 'Parameter description',
	'varible_name' => 'Variable name',
	'type' => "Type",
	'default_value' => 'Default value',
	'sorting' => 'Sort',
	'lib_property_form_title_edit' => 'Edit parameter of sample dynamic page',
	'id' => 'ID',
	'lib_id' => 'Lib Id',
	'lib_property_type_0' => 'Input field',
	'lib_property_type_1' => 'Checkbox',
	'lib_property_type_2' => 'XSL template',
	'lib_property_type_3' => 'List',
	'lib_property_type_4' => 'SQL query',
	'lib_property_type_5' => 'Large text field',
	'lib_property_type_7' => 'TPL template',
	'lib_property_type_8' => 'File',
	'value' => 'Value',
	'multivalue' => 'Multiple values',
	'copy_from' => ' [Copy of %s]',
	'sql_request' => 'SQL query',
	'sql_caption_field' => 'Header field',
	'sql_value_field' => 'Value field',
	'edit_success' => 'Information on dynamic page parameters added/updated successfully.',
	'edit_error' => 'Information on dynamic page parameters added/updated successfully.',
	'apply_success' => 'Information modified successfully',
	'copy_success' => 'Parameters of sample dynamic pages copied successfully.',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'change_filename' => '<acronym title="Conversion of names of all uploaded files for all online store objects - products, groups, additional properties of products and groups">Change names of uploaded files</acronym>',
);
